==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/STATUSAUTHORIZATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour STATUSAUTHORIZATIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="STATUSAUTHORIZATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OLDSTATUS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NEWSTATUS"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "STATUSAUTHORIZATIONID_Type", propOrder = {
    "usergroupid",
    "usercode",
    "entityid",
    "oldstatus",
    "newstatus"
})
public class STATUSAUTHORIZATIONID_Type {

    @XmlElement(name = "USERGROUPID", required = true)
    protected USERGROUPID_Type usergroupid;
    @XmlElement(name = "USERCODE", required = true)
    protected String usercode;
    @XmlElement(name = "ENTITYID", required = true)
    protected ENTITYID_Type entityid;
    @XmlElement(name = "OLDSTATUS", required = true)
    protected STATUS_Type oldstatus;
    @XmlElement(name = "NEWSTATUS", required = true)
    protected STATUS_Type newstatus;

    /**
     * Obtient la valeur de la propriété usergroupid.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Définit la valeur de la propriété usergroupid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

    /**
     * Obtient la valeur de la propriété usercode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERCODE() {
        return usercode;
    }

    /**
     * Définit la valeur de la propriété usercode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERCODE(String value) {
        this.usercode = value;
    }

    /**
     * Obtient la valeur de la propriété entityid.
     * 
     * @return
     *     possible object is
     *     {@link ENTITYID_Type }
     *     
     */
    public ENTITYID_Type getENTITYID() {
        return entityid;
    }

    /**
     * Définit la valeur de la propriété entityid.
     * 
     * @param value
     *     allowed object is
     *     {@link ENTITYID_Type }
     *     
     */
    public void setENTITYID(ENTITYID_Type value) {
        this.entityid = value;
    }

    /**
     * Obtient la valeur de la propriété oldstatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getOLDSTATUS() {
        return oldstatus;
    }

    /**
     * Définit la valeur de la propriété oldstatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setOLDSTATUS(STATUS_Type value) {
        this.oldstatus = value;
    }

    /**
     * Obtient la valeur de la propriété newstatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getNEWSTATUS() {
        return newstatus;
    }

    /**
     * Définit la valeur de la propriété newstatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setNEWSTATUS(STATUS_Type value) {
        this.newstatus = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/STATUSAUTHORIZATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for STATUSAUTHORIZATIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="STATUSAUTHORIZATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OLDSTATUS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NEWSTATUS"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "STATUSAUTHORIZATIONID_Type", propOrder = {
    "usergroupid",
    "usercode",
    "entityid",
    "oldstatus",
    "newstatus"
})
public class STATUSAUTHORIZATIONID_Type {

    @XmlElement(name = "USERGROUPID", required = true)
    protected USERGROUPID_Type usergroupid;
    @XmlElement(name = "USERCODE", required = true)
    protected String usercode;
    @XmlElement(name = "ENTITYID", required = true)
    protected ENTITYID_Type entityid;
    @XmlElement(name = "OLDSTATUS", required = true)
    protected STATUS_Type oldstatus;
    @XmlElement(name = "NEWSTATUS", required = true)
    protected STATUS_Type newstatus;

    /**
     * Gets the value of the usergroupid property.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Sets the value of the usergroupid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

    /**
     * Gets the value of the usercode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERCODE() {
        return usercode;
    }

    /**
     * Sets the value of the usercode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERCODE(String value) {
        this.usercode = value;
    }

    /**
     * Gets the value of the entityid property.
     * 
     * @return
     *     possible object is
     *     {@link ENTITYID_Type }
     *     
     */
    public ENTITYID_Type getENTITYID() {
        return entityid;
    }

    /**
     * Sets the value of the entityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ENTITYID_Type }
     *     
     */
    public void setENTITYID(ENTITYID_Type value) {
        this.entityid = value;
    }

    /**
     * Gets the value of the oldstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getOLDSTATUS() {
        return oldstatus;
    }

    /**
     * Sets the value of the oldstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setOLDSTATUS(STATUS_Type value) {
        this.oldstatus = value;
    }

    /**
     * Gets the value of the newstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getNEWSTATUS() {
        return newstatus;
    }

    /**
     * Sets the value of the newstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setNEWSTATUS(STATUS_Type value) {
        this.newstatus = value;
    }

}
